@@ -1,30 +1,18 @@
-"""
-pycaption
-~~~~~~~~
-
-:copyright: (c) 2012 by PBS
-:license: Apache 2.0
-
-"""
-
-__title__ = 'pycaption'
-__version__ = '0.2.14'
-__author__ = 'Joe Norton'
-__license__ = 'Apache 2.0'
-__copyright__ = 'Copyright 2012 PBS'
-
-from .pycaption import CaptionConverter
+from .base import CaptionConverter
 from .dfxp import DFXPWriter, DFXPReader
 from .sami import SAMIReader, SAMIWriter
 from .srt import SRTReader, SRTWriter
 from .scc import SCCReader, SCCWriter
 from .webvtt import WebVTTReader, WebVTTWriter
+from .exceptions import (
+    CaptionReadError, CaptionReadNoCaptions, CaptionReadSyntaxError)
 
 
 __all__ = [
     'CaptionConverter', 'DFXPReader', 'DFXPWriter',
     'SAMIReader', 'SAMIWriter', 'SRTReader', 'SRTWriter',
     'SCCReader', 'SCCWriter', 'WebVTTReader', 'WebVTTWriter',
+    'CaptionReadError', 'CaptionReadNoCaptions', 'CaptionReadSyntaxError',
     'detect_format'
 ]
 
