@@ -1,9 +1,13 @@
 from bs4 import BeautifulSoup, NavigableString
 from xml.sax.saxutils import escape
 
-from pycaption import BaseReader, BaseWriter, CaptionSet, Caption, CaptionNode
+from .base import (
+    BaseReader, BaseWriter, CaptionSet, Caption, CaptionNode,
+    DEFAULT_LANGUAGE_CODE)
+from .exceptions import CaptionReadNoCaptions
 
-dfxp_base = '''
+
+DFXP_BASE_MARKUP = '''
 <tt xmlns="http://www.w3.org/ns/ttml"
     xmlns:tts="http://www.w3.org/ns/ttml#styling">
     <head>
@@ -31,7 +35,7 @@ class DFXPReader(BaseReader):
 
         # Each div represents all the captions for a single language.
         for div in dfxp_soup.find_all('div'):
-            lang = div.attrs.get('xml:lang', 'en')
+            lang = div.attrs.get('xml:lang', DEFAULT_LANGUAGE_CODE)
             captions.set_captions(lang, self._translate_div(div))
 
         for style in dfxp_soup.find_all('style'):
@@ -42,6 +46,9 @@ class DFXPReader(BaseReader):
 
         captions = self._combine_matching_captions(captions)
 
+        if captions.is_empty():
+            raise CaptionReadNoCaptions("empty caption file")
+
         return captions
 
     def _translate_div(self, div):
@@ -170,7 +177,7 @@ class DFXPWriter(BaseWriter):
         self.open_span = False
 
     def write(self, captions, force=''):
-        dfxp = BeautifulSoup(dfxp_base, 'xml')
+        dfxp = BeautifulSoup(DFXP_BASE_MARKUP, 'xml')
         dfxp.find('tt')['xml:lang'] = "en"
 
         for style_id, style in captions.get_styles():
